@@ -28,6 +28,27 @@
 
 /*
  * $Log: console_interface.c,v $
+ * Revision 1.20  2007-12-19 08:42:35  gerber
+ * debugged
+ *
+ * Revision 1.19  2007-11-23 16:24:07  gerber
+ * release 0.5.0: Kafka
+ *
+ * Revision 1.18  2007-06-06 17:00:48  gerber
+ * Retreives images/data from URI using Gnome Virtual File System.
+ *
+ * Revision 1.17  2007-03-22 16:00:32  gerber
+ * Added image processing tabulator
+ *
+ * Revision 1.16  2007-02-16 17:09:48  gerber
+ * added Gauss weighting on I.A. and SPOF filtering (on correlation function)
+ *
+ * Revision 1.15  2007-01-29 11:27:43  gerber
+ * added image formats png, gif, tif png, bmp, improved buffer display
+ *
+ * Revision 1.14  2006-09-18 07:27:05  gerber
+ * *** empty log message ***
+ *
  * Revision 1.13  2006/01/31 14:28:11  gerber
  * version 0.3.0
  *
@@ -81,9 +102,16 @@
 #include "utils.h"
 #include "console_interface.h"
 #include "console_menus.h"
-#ifndef DISABLE_DAC
-#include "dac.h"
-#endif /* DISABLE_DAC */
+#ifdef ENABLE_CAM
+#include "dac_cam.h"
+#endif /* ENABLE_CAM */
+#ifdef ENABLE_TRIG
+#include "dac_trig.h"
+#endif /* ENABLE_TRIG */
+#ifdef ENABLE_IMGPROC
+#include "imgproc.h"
+#endif /* ENABLE_IMGPROC */
+
 #include "piveval.h"
 #include "pivvalid.h"
 #include "pivpost.h"
@@ -92,14 +120,14 @@
 
 
 GtkWidget *
-create_menu_gpiv_popup(GpivConsole * gpiv
+create_menu_gpiv_popup(GpivConsole *gpiv
                        )
 /*-----------------------------------------------------------------------------
  */
 {
-        GnomeApp * console = gpiv->console;
-        GtkWidget * menu_gpiv_popup = NULL;
-        
+        GnomeApp *console = gpiv->console;
+        GtkWidget *menu_gpiv_popup = NULL;
+
         menu_gpiv_popup = gtk_menu_new();
         gtk_object_set_data (GTK_OBJECT (console),
                              "menu_gpiv_popup",
@@ -194,7 +222,7 @@ create_menu_gpiv_popup(GpivConsole * gpiv
         gtk_object_set_data (GTK_OBJECT (settings_menu_gpiv_popup[0].widget),
                              "gpiv",
                              gpiv);
-        if (gpiv_par.view_gpivbuttons) {
+        if (gpiv_par->console__view_gpivbuttons) {
                 gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
                                                 (settings_menu_gpiv_popup[0].
                                                  widget), 
@@ -216,7 +244,7 @@ create_menu_gpiv_popup(GpivConsole * gpiv
         gtk_object_set_data (GTK_OBJECT (settings_menu_gpiv_popup[1].widget),
                              "gpiv",
                              gpiv);
-        if (gpiv_par.view_tabulator) {
+        if (gpiv_par->console__view_tabulator) {
                 gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
                                                 (settings_menu_gpiv_popup[1].
                                                  widget), 
@@ -244,7 +272,7 @@ create_menu_gpiv_popup(GpivConsole * gpiv
 
 
 
-        if (gpiv_par.show_tooltips) {
+        if (gpiv_par->console__show_tooltips) {
                 gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
                                                 (help_menu_gpiv_popup[0].
                                                  widget), 
@@ -270,27 +298,27 @@ create_gpiv (void
  */
 {
         GpivConsole *gpiv = g_new0 (GpivConsole, 1);
-
+	GdkPixbuf *logo = NULL;
+        gint i;
 
         gpiv->tooltips = gtk_tooltips_new ();
 
-
 /*
  * Gnome2: from book Official dev.Guide
  */
+ 	logo = gdk_pixbuf_new_from_file(PIXMAPSDIR "gpiv_logo.png", NULL);
+
         gpiv->console = g_object_new(GNOME_TYPE_APP,
                                      "title", "gpiv console",
                                      "app-id", "gpiv",
-                                     "default-width", 300,
-                                     "default-height", 400,
+                                     "default-width",  CONSOLE_WIDTH,
+                                     "default-height", CONSOLE_HEIGHT,
+                                     "icon", logo,
                                      NULL);
+        if (logo != NULL) g_object_unref (logo);
         
         
         
-/*         gtk_window_set_policy (GTK_WINDOW (gpiv->console), */
-/*                                FALSE,  */
-/*                                TRUE,  */
-/*                                TRUE); */
         gtk_object_set_data (GTK_OBJECT (gpiv->console),
                              "gpiv",
                              gpiv);
@@ -300,6 +328,7 @@ create_gpiv (void
                           NULL);
         
         
+
         gpiv->dock1 = GNOME_APP (gpiv->console)->dock;
         gtk_widget_ref (gpiv->dock1);
         gtk_object_set_data_full (GTK_OBJECT (gpiv->console),
@@ -539,23 +568,24 @@ create_gpiv (void
         
         
         
-        gpiv->button_print = 
-                (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-print");
-        gtk_widget_show (gpiv->button_print);
-        gtk_container_add (GTK_CONTAINER (gpiv->toolbar1), 
-                           gpiv->button_print);
-        gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (gpiv->button_print), 
-                                   gpiv->tooltips, 
-                                   _("Print the displayed data of active buffer(s)"),
-                                   NULL);
+/*         gpiv->button_print =  */
+/*                 (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-print"); */
+/*         gtk_widget_show (gpiv->button_print); */
+/*         gtk_container_add (GTK_CONTAINER (gpiv->toolbar1),  */
+/*                            gpiv->button_print); */
+/*         gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (gpiv->button_print),  */
+/*                                    gpiv->tooltips,  */
+/*                                    _("Print the displayed data of active buffer(s)"), */
+/*                                    NULL); */
         
-        gtk_object_set_data (GTK_OBJECT (gpiv->button_print),
-                        "gpiv",
-                             gpiv);
-        g_signal_connect (GTK_OBJECT (gpiv->button_print),
-                          "clicked",
-                          G_CALLBACK (on_print_activate), 
-                          NULL);
+/*         gtk_object_set_data (GTK_OBJECT (gpiv->button_print), */
+/*                              "gpiv", */
+/*                              gpiv); */
+/*         g_signal_connect (GTK_OBJECT (gpiv->button_print), */
+/*                           "clicked", */
+/*                           G_CALLBACK (on_print_activate),  */
+/*                           NULL); */
+/*         gtk_widget_hide (GTK_WIDGET (gpiv->button_print)); */
         
         
         
@@ -764,50 +794,136 @@ create_gpiv (void
 
 
 
-#ifndef DISABLE_DAC
+#ifdef ENABLE_CAM
 /*
- * dac process button
+ * camera process button
  */
-    gpiv->button_toolbar_dac = gtk_check_button_new_with_label(_("record"));
-    gtk_widget_ref(gpiv->button_toolbar_dac);
+    gpiv->button_toolbar_cam = gtk_check_button_new_with_label(_("camera"));
+    gtk_widget_ref(gpiv->button_toolbar_cam);
     gtk_object_set_data_full(GTK_OBJECT(gpiv->console),
-			     "button_toolbar_dac",
-                             gpiv->button_toolbar_dac,
+			     "button_toolbar_cam",
+                             gpiv->button_toolbar_cam,
 			     (GtkDestroyNotify) gtk_widget_unref);
-    gtk_widget_show(gpiv->button_toolbar_dac);
+    gtk_widget_show(gpiv->button_toolbar_cam);
     gtk_box_pack_start(GTK_BOX(gpiv->hbox_toolbar2),
-                       gpiv->button_toolbar_dac,
+                       gpiv->button_toolbar_cam,
                        FALSE,
 		       FALSE,
                        0);
     gtk_tooltips_set_tip(gpiv->tooltips,
-                         gpiv->button_toolbar_dac,
- 			 _("Enables data acquisition for chain processing: recording of images (pairs). \n\
+                         gpiv->button_toolbar_cam,
+ 			 _("Enables camera for image recording within the chain process. \n\
 The process will be executed by clicking the Execute button"),
                          NULL);
 
-    gtk_object_set_data(GTK_OBJECT(gpiv->button_toolbar_dac), 
+    gtk_object_set_data(GTK_OBJECT(gpiv->button_toolbar_cam), 
 			"gpiv",
                         gpiv);
-    gtk_signal_connect(GTK_OBJECT(gpiv->button_toolbar_dac), 
+    gtk_signal_connect(GTK_OBJECT(gpiv->button_toolbar_cam), 
                        "enter",
-		       G_CALLBACK (on_button_dac_recstart_enter),
+		       G_CALLBACK (on_button_dac_camstart_enter),
                        NULL);
-    gtk_signal_connect(GTK_OBJECT(gpiv->button_toolbar_dac), 
+    gtk_signal_connect(GTK_OBJECT(gpiv->button_toolbar_cam), 
                        "leave",
 		       G_CALLBACK (on_widget_leave),
                        NULL);
-    gtk_signal_connect(GTK_OBJECT(gpiv->button_toolbar_dac), 
+    gtk_signal_connect(GTK_OBJECT(gpiv->button_toolbar_cam), 
                        "clicked",
-		       G_CALLBACK (on_toolbar_checkbutton_dac),
+		       G_CALLBACK (on_toolbar_checkbutton_cam),
                        NULL);
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
-                                (gpiv->button_toolbar_dac),
-                                gpiv_par.process_dac);
+                                (gpiv->button_toolbar_cam),
+                                gpiv_par->process__cam);
 
-#endif /* DISABLE_DAC */
+#endif /* ENABLE_CAM */
 
 
+#ifdef ENABLE_TRIG
+/*
+ * trigger process button
+ */
+    gpiv->button_toolbar_trig = gtk_check_button_new_with_label(_("trigger"));
+    gtk_widget_ref(gpiv->button_toolbar_trig);
+    gtk_object_set_data_full(GTK_OBJECT(gpiv->console),
+			     "button_toolbar_trig",
+                             gpiv->button_toolbar_trig,
+			     (GtkDestroyNotify) gtk_widget_unref);
+    gtk_widget_show(gpiv->button_toolbar_trig);
+    gtk_box_pack_start(GTK_BOX(gpiv->hbox_toolbar2),
+                       gpiv->button_toolbar_trig,
+                       FALSE,
+		       FALSE,
+                       0);
+    gtk_tooltips_set_tip(gpiv->tooltips,
+                         gpiv->button_toolbar_trig,
+ 			 _("Enables (RTAI) camera and laser triggering within the chain process. \n\
+The process will be executed by clicking the Execute button"),
+                         NULL);
+
+    gtk_object_set_data(GTK_OBJECT(gpiv->button_toolbar_trig), 
+			"gpiv",
+                        gpiv);
+    gtk_signal_connect(GTK_OBJECT(gpiv->button_toolbar_trig), 
+                       "enter",
+		       G_CALLBACK (on_button_dac_triggerstart_enter),
+                       NULL);
+    gtk_signal_connect(GTK_OBJECT(gpiv->button_toolbar_trig), 
+                       "leave",
+		       G_CALLBACK (on_widget_leave),
+                       NULL);
+    gtk_signal_connect(GTK_OBJECT(gpiv->button_toolbar_trig), 
+                       "clicked",
+		       G_CALLBACK (on_toolbar_checkbutton_trig),
+                       NULL);
+    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
+                                (gpiv->button_toolbar_trig),
+                                gpiv_par->process__trig);
+
+#endif /* ENABLE_TRIG */
+
+
+#ifdef ENABLE_IMGPROC
+/*
+ * Image processing button
+ */
+    gpiv->button_toolbar_imgproc = gtk_check_button_new_with_label(_("image"));
+    gtk_widget_ref(gpiv->button_toolbar_imgproc);
+    gtk_object_set_data_full(GTK_OBJECT(gpiv->console),
+			     "button_toolbar_imgproc",
+                             gpiv->button_toolbar_imgproc,
+			     (GtkDestroyNotify) gtk_widget_unref);
+    gtk_widget_show(gpiv->button_toolbar_imgproc);
+    gtk_box_pack_start(GTK_BOX(gpiv->hbox_toolbar2),
+                       gpiv->button_toolbar_imgproc,
+                       FALSE,
+		       FALSE,
+                       0);
+    gtk_tooltips_set_tip(gpiv->tooltips,
+                         gpiv->button_toolbar_imgproc,
+ 			 _("Enables image processing within the chain process. \n\
+The process will be executed by clicking the Execute button"),
+                         NULL);
+
+    gtk_object_set_data(GTK_OBJECT(gpiv->button_toolbar_imgproc), 
+			"gpiv",
+                        gpiv);
+    g_signal_connect(GTK_OBJECT(gpiv->button_toolbar_imgproc), 
+                       "enter",
+		       G_CALLBACK (on_button_imgproc_enter),
+                       NULL);
+    g_signal_connect(GTK_OBJECT(gpiv->button_toolbar_imgproc), 
+                       "leave",
+		       G_CALLBACK (on_widget_leave),
+                       NULL);
+    g_signal_connect(GTK_OBJECT(gpiv->button_toolbar_imgproc), 
+                       "clicked",
+		       G_CALLBACK (on_toolbar_checkbutton_imgproc),
+                       NULL);
+    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
+                                (gpiv->button_toolbar_imgproc),
+                                gpiv_par->process__imgproc);
+
+#endif /* ENABLE_IMGPROC */
 /*
  * piv process button
  */
@@ -825,7 +941,7 @@ The process will be executed by clicking the Execute button"),
                             0);
         gtk_tooltips_set_tip (gpiv->tooltips,
                               gpiv->button_toolbar_piv,
-                              _("Enables PIV for chain processing: analysing of a PIV image \
+                              _("Enables PIV image interrogation for chain processing: analysing of a PIV image \
  (pair), resulting into the mean displacements of the particle images within \
 each interrogation area. \n\
 The process will be executed by clicking the Execute button"),
@@ -848,7 +964,7 @@ The process will be executed by clicking the Execute button"),
                           NULL);
         gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
                                      (gpiv->button_toolbar_piv),
-                                     gpiv_par.process_piv);
+                                     gpiv_par->process__piv);
         
         
         
@@ -889,7 +1005,7 @@ The process will be executed by clicking the Execute button"),
                           NULL);
         gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
                                      (gpiv->button_toolbar_gradient),
-                                     gpiv_par.process_gradient);
+                                     gpiv_par->process__gradient);
         
 
         
@@ -930,7 +1046,7 @@ The process will be executed by clicking the Execute button"),
                           NULL);
         gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
                                      (gpiv->button_toolbar_resstats),
-                                     gpiv_par.process_resstats);
+                                     gpiv_par->process__resstats);
        
         
         
@@ -971,7 +1087,7 @@ The process will be executed by clicking the Execute button"),
                           NULL);
         gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
                                      (gpiv->button_toolbar_errvec),
-                                     gpiv_par.process_errvec);
+                                     gpiv_par->process__errvec);
        
         
         
@@ -991,7 +1107,7 @@ The process will be executed by clicking the Execute button"),
         gtk_tooltips_set_tip (gpiv->tooltips,
                               gpiv->button_toolbar_peaklock, 
                               _("Enables peak-lock for chain processing: shows an histogram \
-of sub-pixel displacements in order to check on peak-locking effects. \
+of sub-pixel displacements to check on peak-locking effects. \
  The histogram will be displayed in the Piv Validation tab. \n\
 The process will be executed by clicking the \"Execute\" button"),
                               NULL);
@@ -1013,7 +1129,7 @@ The process will be executed by clicking the \"Execute\" button"),
                           NULL);
         gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
                                      (gpiv->button_toolbar_peaklock),
-                                     gpiv_par.process_peaklock);
+                                     gpiv_par->process__peaklock);
        
         
         gpiv->button_toolbar_scale =
@@ -1052,7 +1168,7 @@ over all data. \
                           NULL);
         gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
                                      (gpiv->button_toolbar_scale),
-                                     gpiv_par.process_scale);
+                                     gpiv_par->process__scale);
        
 
         gpiv->button_toolbar_average =
@@ -1091,7 +1207,7 @@ over all data. \
                           NULL);
         gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
                                      (gpiv->button_toolbar_average),
-                                     gpiv_par.process_average);
+                                     gpiv_par->process__average);
         
 
         gpiv->button_toolbar_subavg =
@@ -1131,7 +1247,7 @@ from all data. \
                           NULL);
         gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
                                      (gpiv->button_toolbar_subavg),
-                                     gpiv_par.process_subtract);
+                                     gpiv_par->process__subtract);
         
         
         gpiv->button_toolbar_vorstra =
@@ -1171,7 +1287,7 @@ The process will be executed by clicking the Execute button"),
                           NULL);
         gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
                                      (gpiv->button_toolbar_vorstra),
-                                     gpiv_par.process_vorstra);
+                                     gpiv_par->process__vorstra);
         
         
         
@@ -1210,7 +1326,10 @@ The process will be executed by clicking the Execute button"),
                             0);
         
         
-#ifndef DISABLE_DAC
+#ifdef ENABLE_DAC
+/*
+ * Tabulator for Data Acquisition
+ */
         gpiv->dac = create_dac (GNOME_APP(gpiv->console),
                                   gpiv->notebook);
         
@@ -1227,9 +1346,11 @@ The process will be executed by clicking the Execute button"),
                                                         (gpiv->notebook), 
                                                         PAGE_DAC)),
                  GTK_WIDGET(gpiv->tablabel_dac));
-        
-#endif /* DISABLE_DAC */
-        
+#endif /* ENABLE_DAC */        
+
+/*
+ * Tabulator for Image header
+ */
         gpiv->imgh = create_imgh (GNOME_APP(gpiv->console),
                                   gpiv->notebook);
         
@@ -1250,14 +1371,50 @@ The process will be executed by clicking the Execute button"),
         
         
         gtk_object_set_data (GTK_OBJECT (gpiv->imgh->radiobutton_mouse_1), 
+                             "gpiv",
+                             gpiv);                
+
+
+#ifdef ENABLE_IMGPROC
+/*
+ * Tabulator for Image processing
+ */
+        gpiv->imgproc = create_imgproc (GNOME_APP(gpiv->console),
+                                  gpiv->notebook);
+        
+        gpiv->tablabel_imgproc = gtk_label_new ( _("Process"));
+        gtk_widget_ref (gpiv->tablabel_imgproc);
+        gtk_object_set_data_full (GTK_OBJECT (gpiv->console), 
+                                  "tablabel_imgproc",
+                                  gpiv->tablabel_imgproc,
+                                  (GtkDestroyNotify) gtk_widget_unref);
+        gtk_widget_show (gpiv->tablabel_imgproc);
+        gtk_notebook_set_tab_label 
+                (GTK_NOTEBOOK (gpiv->notebook),
+                 GTK_WIDGET (gtk_notebook_get_nth_page (GTK_NOTEBOOK
+                                                        (gpiv->notebook), 
+                                                        PAGE_IMGPROC)),
+                 GTK_WIDGET (gpiv->tablabel_imgproc));
+
+
+        for (i = 0; i < IMG_FILTERS; i++) {
+        gtk_object_set_data (GTK_OBJECT (gpiv->imgproc->imf_inf[i]->button_filter), 
                              "gpiv",
                              gpiv);
-        
-        
-        
+        }
+
+        gtk_object_set_data (GTK_OBJECT (gpiv->imgproc->button), 
+                             "gpiv",
+                             gpiv);
+
+#endif
+
+/*
+ * Tabulator for Interrogation
+ */
         gpiv->piveval = create_piveval (GNOME_APP(gpiv->console),
                                         gpiv->notebook);
-        gpiv->tablabel_piveval = gtk_label_new ( _("Interrogation"));
+        gpiv->tablabel_piveval = gtk_label_new ( _("Interrogate"));
         gtk_widget_ref (gpiv->tablabel_piveval);
         gtk_object_set_data_full (GTK_OBJECT (gpiv->console), 
                                   "tablabel_piveval",
@@ -1273,6 +1430,9 @@ The process will be executed by clicking the Execute button"),
         
         
         
+        gtk_object_set_data (GTK_OBJECT (gpiv->piveval->radiobutton_mouse_0), 
+                             "gpiv",
+                             gpiv);
         gtk_object_set_data (GTK_OBJECT (gpiv->piveval->radiobutton_mouse_1), 
                              "gpiv",
                              gpiv);
@@ -1291,9 +1451,6 @@ The process will be executed by clicking the Execute button"),
         gtk_object_set_data (GTK_OBJECT (gpiv->piveval->radiobutton_mouse_6), 
                              "gpiv",
                              gpiv);
-        gtk_object_set_data (GTK_OBJECT (gpiv->piveval->radiobutton_mouse_7), 
-                             "gpiv",
-                             gpiv);
         gtk_object_set_data (GTK_OBJECT (gpiv->piveval->checkbutton_monitor), 
                              "gpiv",
                              gpiv);
@@ -1330,6 +1487,12 @@ The process will be executed by clicking the Execute button"),
         gtk_object_set_data (GTK_OBJECT (gpiv->piveval->radiobutton_imgdeform), 
                              "gpiv",
                              gpiv);
+        gtk_object_set_data (GTK_OBJECT (gpiv->piveval->checkbutton_weight_ia),
+                             "gpiv",
+                             gpiv);
+        gtk_object_set_data (GTK_OBJECT (gpiv->piveval->checkbutton_spof),
+                             "gpiv",
+                             gpiv);
 /*     gtk_object_set_data (GTK_OBJECT (gpiv->piveval->spinbutton_monitor_zoom),  */
 /*                         "gpiv", */
 /*                         gpiv); */
@@ -1341,10 +1504,13 @@ The process will be executed by clicking the Execute button"),
                              gpiv);
         
         
+/*
+ * Tabulator for PIV-data validation
+ */
         gpiv->pivvalid = create_pivvalid (GNOME_APP(gpiv->console),
                                           gpiv->notebook);
         
-        gpiv->tablabel_pivvalid = gtk_label_new ( _("Validation"));
+        gpiv->tablabel_pivvalid = gtk_label_new ( _("Validate"));
         gtk_widget_ref (gpiv->tablabel_pivvalid);
         gtk_object_set_data_full (GTK_OBJECT (gpiv->console),
                                   "tablabel_pivvalid",
@@ -1430,8 +1596,9 @@ The process will be executed by clicking the Execute button"),
                         "gpiv",
                              gpiv);
 
-
-
+/*
+ * Tabulator for PIV-data post-processing
+ */
 
 /* pivpost->checkbutton_scale */
         gpiv->pivpost = create_pivpost (GNOME_APP(gpiv->console),
@@ -1440,7 +1607,7 @@ The process will be executed by clicking the Execute button"),
 /*                         "gpiv", */
 /*                         gpiv); */
 
-        gpiv->tablabel_pivpost = gtk_label_new ( _("Post processing"));
+        gpiv->tablabel_pivpost = gtk_label_new ( _("Post process"));
         gtk_widget_ref (gpiv->tablabel_pivpost);
         gtk_object_set_data_full (GTK_OBJECT (gpiv->console), 
                                   "tablabel_pivpost",
@@ -1462,9 +1629,6 @@ The process will be executed by clicking the Execute button"),
         gtk_object_set_data (GTK_OBJECT (gpiv->pivpost->button_savg), 
                              "gpiv",
                              gpiv);
-        gtk_object_set_data (GTK_OBJECT (gpiv->pivpost->button_addavg), 
-                             "gpiv",
-                             gpiv);
         gtk_object_set_data (GTK_OBJECT (gpiv->pivpost->button_subavg), 
                              "gpiv",
                              gpiv);
@@ -1506,7 +1670,7 @@ The process will be executed by clicking the Execute button"),
                           G_CALLBACK (on_notebook_switch_page), 
                           NULL);
         gtk_notebook_set_page (GTK_NOTEBOOK (gpiv->notebook),
-                               gpiv_var.tab_pos);
+                               gpiv_var->tab_pos);
 
 /*
  * handlebox of buffer list
@@ -1594,7 +1758,7 @@ The process will be executed by clicking the Execute button"),
                                      400);
         
    
-#ifdef GTK2
+#ifdef GTK4
 enum
 {
         BUFFER_NUMBER,
@@ -1629,7 +1793,7 @@ enum
                               NULL);
         gtk_clist_set_column_width (GTK_CLIST (gpiv->clist_buf), 
                                     0, 
-                                    10);
+                                    15);
         gtk_clist_set_column_width (GTK_CLIST (gpiv->clist_buf), 
                                     1, 
                                     80);
@@ -1695,10 +1859,10 @@ enum
         
         
         gtk_drag_dest_set (GTK_WIDGET (gpiv->clist_buf),
-                           GTK_DEST_DEFAULT_ALL,
-                           target_table, 1,
+                           GTK_DEST_DEFAULT_DROP,
+                           target_table, 
+                           G_N_ELEMENTS (target_table),
                            GDK_ACTION_COPY);
-        
         g_signal_connect (GTK_OBJECT (gpiv->clist_buf), 
                           "drag_data_received",
                           G_CALLBACK (on_clist_buf_drag_data_received),
@@ -1727,7 +1891,7 @@ enum
 /*
  * set gpiv->menubars after definition of all console widgets
  */
-        if (gpiv_par.view_gpivbuttons) {
+        if (gpiv_par->console__view_gpivbuttons) {
                 gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
                                                 (settings_menu_gpiv[0].widget), 
                                                 TRUE);
@@ -1738,7 +1902,7 @@ enum
         }
         
         
-        if (gpiv_par.view_tabulator) {
+        if (gpiv_par->console__view_tabulator) {
                 gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
                                                 (settings_menu_gpiv[1].widget), 
                                                 TRUE);
@@ -1749,7 +1913,7 @@ enum
         }
         
         
-        if (gpiv_par.show_tooltips) {
+        if (gpiv_par->console__show_tooltips) {
                 gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
                                                 (help_menu_gpiv[0].widget), 
                                                 TRUE);
