@@ -43,7 +43,7 @@
  * (Firewire) IIDC compliant camera's
  *
  */
-#ifndef DISABLE_DAC
+#ifdef ENABLE_DAC
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -53,11 +53,19 @@
 #include "utils.h"
 #include "console.h"
 #include "dac.h"
+
+#ifdef ENABLE_CAM
 #include "dac_cam.h"
+#endif
+
+#ifdef ENABLE_TRIG
+#include "dac_trig.h"
+#endif
+
 #include "pivpost.h"
 
 
-
+#ifdef ENABLE_CAM
 static void
 create_camera_menu(GnomeApp *main_window,
                    Cam *cam
@@ -116,10 +124,10 @@ create_camera_menu(GnomeApp *main_window,
 /*
  * BUGFIX apply last camera to img_par.source
  */
-            g_snprintf(image_par.source, GPIV_MAX_CHARS, "%s %s", 
+            g_snprintf(gl_image_par.source, GPIV_MAX_CHARS, "%s %s", 
                        cam_var.camera[i].vendor,
                        cam_var.camera[i].model);
-            image_par.source_logic = TRUE;
+            gl_image_par.source__set = TRUE;
         }
     } else {
         g_snprintf(tmp,
@@ -132,8 +140,8 @@ create_camera_menu(GnomeApp *main_window,
         gtk_option_menu_set_menu (GTK_OPTION_MENU (cam->camera_select), 
                                   cam->camera_select_menu);
 
-        g_snprintf(image_par.source, GPIV_MAX_CHARS, "No camera");
-        image_par.source_logic = TRUE;
+        g_snprintf(gl_image_par.source, GPIV_MAX_CHARS, "No camera");
+        gl_image_par.source__set = TRUE;
     }
 
 
@@ -344,8 +352,8 @@ create_format_menu(GnomeApp *main_window,
 
 static void
 create_fps_menu(GnomeApp *main_window,
-                   Cam *cam
-                   )
+                Cam *cam
+                )
 /*-----------------------------------------------------------------------------
  * From coriander: build_menus.c BuildCameraMenu
  */
@@ -756,7 +764,7 @@ create_camera_feature_menu_scale(GnomeApp *main_window,
                       0);
 }
 
-
+#endif /* ENABLE_CAM */
 
 
 Dac *
@@ -767,14 +775,19 @@ create_dac (GnomeApp *main_window,
  * Image Info window with data from header
  */
 {
-    GpivConsole * gpiv = gtk_object_get_data(GTK_OBJECT (main_window), "gpiv");
-    Dac * dac = g_new0(Dac, 1);
+    GpivConsole *gpiv = gtk_object_get_data(GTK_OBJECT (main_window), "gpiv");
+    Dac *dac = g_new0 (Dac, 1);
     gint i;
     gchar *fname_last_base = NULL;
 
 
-    dac->trig = g_new0(Trig, 1);
-    dac->cam = g_new0(Cam, 1);
+/* #ifdef ENABLE_TRIG */
+    dac->trig = g_new0 (Trig, 1);
+/* #endif */
+
+#ifdef ENABLE_CAM
+    dac->cam = g_new0 (Cam, 1);
+#endif
 
 
 
@@ -791,7 +804,15 @@ create_dac (GnomeApp *main_window,
 
 
 /* Data Acquisition */
+#ifdef ENABLE_CAM
+#ifdef ENABLE_TRIG
     dac->label_title = gtk_label_new(_("Camera-laser trigger settings and image recording"));
+#else
+    dac->label_title = gtk_label_new(_("Camera settings and image recording"));
+#endif /* ENABLE_TRIG */
+#else /* ENABLE_CAM */
+    dac->label_title = gtk_label_new(_("Trigger settings"));
+#endif /* ENABLE_CAM */
     gtk_widget_ref(dac->label_title);
     gtk_object_set_data_full(GTK_OBJECT (main_window),
 			     "dac->label_title",
@@ -1089,7 +1110,15 @@ create_dac (GnomeApp *main_window,
 /*
  * frame, table, mouse selection and spinners for triggering"
  */
-    dac->trig->frame_trigger = gtk_frame_new(_("Timing & triggering"));
+#ifdef ENABLE_CAM
+#ifdef ENABLE_TRIG
+    dac->trig->frame_trigger = gtk_frame_new(_("Trigger and timing"));
+#else
+    dac->trig->frame_trigger = gtk_frame_new(_("Timing"));
+#endif /* ENABLE_TRIG */
+#else
+    dac->trig->frame_trigger = gtk_frame_new(_("Trigger"));
+#endif /* ENABLE_CAM */
     gtk_widget_ref(dac->trig->frame_trigger);
     gtk_object_set_data_full(GTK_OBJECT (main_window),
 			     "dac_frame_trigger",
@@ -1222,6 +1251,7 @@ create_dac (GnomeApp *main_window,
 
 
 
+#ifdef ENABLE_TRIG
     dac->trig->radiobutton_mouse_3 =
 	gtk_radio_button_new_with_label(dac->trig->mouse_trigger_group,
 					_("Interrupt one shot"));
@@ -1398,9 +1428,9 @@ create_dac (GnomeApp *main_window,
 
 
     dac->trig->spinbutton_adj_trigger_dt =
-	gtk_adjustment_new(dac_par.ttime.dt * GPIV_NANO2MILI,
-			   GPIV_DACPAR_TTIME_DT_MIN, 
-			   GPIV_DACPAR_TTIME_DT_MAX, 
+	gtk_adjustment_new(trig_par.ttime.dt * GPIV_NANO2MILI,
+			   GPIV_TRIGPAR_TTIME_DT_MIN, 
+			   GPIV_TRIGPAR_TTIME_DT_MAX, 
 			   ADJ_PAGE,
 			   ADJ_IPAGE,
 			   ADJ_IPAGE);
@@ -1458,9 +1488,9 @@ create_dac (GnomeApp *main_window,
 
 
     dac->trig->spinbutton_adj_trigger_incrdt =
-	gtk_adjustment_new(dac_par.ttime.dt * GPIV_NANO2MILI,
-			   GPIV_DACPAR_TTIME_INCR_DT_MIN, 
-			   GPIV_DACPAR_TTIME_INCR_DT_MAX, 
+	gtk_adjustment_new(trig_par.ttime.dt * GPIV_NANO2MILI,
+			   GPIV_TRIGPAR_TTIME_INCR_DT_MIN, 
+			   GPIV_TRIGPAR_TTIME_INCR_DT_MAX, 
 			   ADJ_PAGE,
 			   ADJ_IPAGE,
 			   ADJ_IPAGE);
@@ -1519,9 +1549,9 @@ create_dac (GnomeApp *main_window,
 
 
     dac->trig->spinbutton_adj_trigger_cap =
-	gtk_adjustment_new(dac_par.ttime.cam_acq_period * GPIV_NANO2MILI,
-			   GPIV_DACPAR_TTIME_CAP_MIN, 
-			   GPIV_DACPAR_TTIME_CAP_MAX, 
+	gtk_adjustment_new(trig_par.ttime.cam_acq_period * GPIV_NANO2MILI,
+			   GPIV_TRIGPAR_TTIME_CAP_MIN, 
+			   GPIV_TRIGPAR_TTIME_CAP_MAX, 
 			   ADJ_ISTEP,
 			   ADJ_IPAGE,
 			   ADJ_IPAGE  /* ADJ_MAX */);
@@ -1550,6 +1580,7 @@ create_dac (GnomeApp *main_window,
 		       "changed",
                      G_CALLBACK (on_spinbutton_dac_trigger_cap),
                      dac->trig->spinbutton_trigger_cap);
+#endif /* ENABLE_TRIG */
 
 
 
@@ -1577,14 +1608,25 @@ create_dac (GnomeApp *main_window,
 
 
 
+#ifdef ENABLE_CAM
     dac->trig->spinbutton_adj_trigger_nf =
-	gtk_adjustment_new(dac_par.ttime.cycles,
-			   GPIV_DACPAR_TTIME_CYCLES_MIN, 
-			   MAX_BUFS, /* GPIV_DACPAR_TTIME_CYCLES_MAX */
+	gtk_adjustment_new(gl_cam_par.cycles,
+			   GPIV_CAMPAR_CYCLES_MIN, 
+			   MAX_BUFS, /* GPIV_CAMPAR_CYCLES_MAX */
 			   ADJ_ISTEP,
 			   ADJ_IPAGE,
 			   MAX_BUFS);
-
+#else /* ENABLE_CAM */
+#ifdef ENABLE_TRIG
+    dac->trig->spinbutton_adj_trigger_nf =
+	gtk_adjustment_new(trig_par.ttime.cycles,
+			   GPIV_TRIGPAR_TTIME_CYCLES_MIN, 
+			   MAX_BUFS, /* GPIV_TRIGPAR_CYCLES_MAX */
+			   ADJ_ISTEP,
+			   ADJ_IPAGE,
+			   MAX_BUFS);
+#endif /* ENABLE_TRIG */
+#endif /* ENABLE_CAM */
     dac->trig->spinbutton_trigger_nf =
 	gtk_spin_button_new(GTK_ADJUSTMENT(dac->trig->spinbutton_adj_trigger_nf),
 			    1,
@@ -1611,12 +1653,12 @@ create_dac (GnomeApp *main_window,
                      dac->trig->spinbutton_trigger_nf);
 
 
-
 /*
  * Trigger starting button
  */
+#ifdef ENABLE_TRIG
     dac->trig->button_trigger_start = 
-        gtk_button_new_with_label(_("start timings"));
+        gtk_button_new_with_label(_("start trigger"));
     gtk_widget_ref(dac->trig->button_trigger_start);
     gtk_object_set_data_full(GTK_OBJECT (main_window),
 			     "button_trigger_start",
@@ -1661,7 +1703,7 @@ create_dac (GnomeApp *main_window,
 /*
  * Trigger stop button
  */
-    dac->trig->button_trigger_stop = gtk_button_new_with_label(_("stop timings"));
+    dac->trig->button_trigger_stop = gtk_button_new_with_label(_("stop trigger"));
     gtk_widget_ref(dac->trig->button_trigger_stop);
     gtk_object_set_data_full(GTK_OBJECT (main_window),
 			     "button_trigger_stop",
@@ -1698,11 +1740,18 @@ create_dac (GnomeApp *main_window,
 		       "clicked",
 		       G_CALLBACK (on_button_dac_triggerstop),
 		       NULL);
+#endif /* ENABLE_TRIG */
 
 
 /*
  * frame, table, for camera settings"
  */
+/* BUGFIX: splitting up interface of cam and trig */
+/* #ifdef ENABLE_CAM2 */
+/*     dac->cam = create_cam(GNOME_APP(gpiv->console), */
+/*                           GTK_TABLE(dac->table) */
+/* #endif */ /* ENABLE_CAM2 */
+#ifdef ENABLE_CAM
     dac->cam->frame_cam = gtk_frame_new(_("Camera"));
     gtk_widget_ref(dac->cam->frame_cam);
     gtk_object_set_data_full(GTK_OBJECT (main_window),
@@ -1819,7 +1868,7 @@ create_dac (GnomeApp *main_window,
 		      dac->cam->trigger_external);
     gtk_widget_set_sensitive (dac->cam->trigger_external, 
                             FALSE);
-  g_signal_connect (GTK_OBJECT (dac->cam->trigger_external), "toggled",
+    g_signal_connect (GTK_OBJECT (dac->cam->trigger_external), "toggled",
                       GTK_SIGNAL_FUNC (on_trigger_external_toggled),
                       NULL);
 
@@ -1848,7 +1897,7 @@ create_dac (GnomeApp *main_window,
 /*
  * Enable triggering with the cam
  */
-
+#ifdef ENABLE_TRIG
     dac->cam->checkbutton_camera_trigger = 
         gtk_check_button_new_with_label(_("RTAI triggering"));
     gtk_widget_ref(dac->cam->checkbutton_camera_trigger);
@@ -1884,7 +1933,7 @@ create_dac (GnomeApp *main_window,
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
                                 (dac->cam->checkbutton_camera_trigger),
                                 gpiv_par.trigger_cam);
-
+#endif /* ENABLE_TRIG */
 
 
 
@@ -2092,15 +2141,15 @@ create_dac (GnomeApp *main_window,
 /*
  * Record activating button
  */
-    dac->cam->button_rec_start = gtk_button_new_with_label(_("record"));
-    gtk_widget_ref(dac->cam->button_rec_start);
+    dac->cam->button_cam_start = gtk_button_new_with_label(_("start camera"));
+    gtk_widget_ref(dac->cam->button_cam_start);
     gtk_object_set_data_full(GTK_OBJECT (main_window),
-			     "button_rec_start",
-			     dac->cam->button_rec_start,
+			     "button_cam_start",
+			     dac->cam->button_cam_start,
 			     (GtkDestroyNotify) gtk_widget_unref);
-    gtk_widget_show(dac->cam->button_rec_start);
+    gtk_widget_show(dac->cam->button_cam_start);
     gtk_table_attach(GTK_TABLE(dac->table),
-		     dac->cam->button_rec_start, 
+		     dac->cam->button_cam_start, 
 		     0, 
 		     1, 
 		     2, 
@@ -2110,45 +2159,45 @@ create_dac (GnomeApp *main_window,
 		     0,
 		     0);
     gtk_tooltips_set_tip(gpiv->tooltips,
-			 dac->cam->button_rec_start,
-			 _("Records PIV images of an area that is illuminated "
+			 dac->cam->button_cam_start,
+			 _("Starts camera to record PIV images of an area that is illuminated "
                            "by a (double cavity Nd-YAG) laser and is observed "
                            "by a CCD camera. Camera and lasers are eventually "
                            "triggered by TTL pulses from the (parallel) output "
                            "port."),
 			 NULL);
 
-    gtk_object_set_data(GTK_OBJECT (dac->cam->button_rec_start),
+    gtk_object_set_data(GTK_OBJECT (dac->cam->button_cam_start),
 			"gpiv",
 			gpiv);
-    g_signal_connect(GTK_OBJECT (dac->cam->button_rec_start),
+    g_signal_connect(GTK_OBJECT (dac->cam->button_cam_start),
 		       "enter",
-		       G_CALLBACK (on_button_dac_recstart_enter),
+		       G_CALLBACK (on_button_dac_camstart_enter),
 		       NULL);
-    g_signal_connect(GTK_OBJECT (dac->cam->button_rec_start),
+    g_signal_connect(GTK_OBJECT (dac->cam->button_cam_start),
 		       "leave",
 		       G_CALLBACK (on_widget_leave),
 		       NULL);
-    g_signal_connect(GTK_OBJECT (dac->cam->button_rec_start),
+    g_signal_connect(GTK_OBJECT (dac->cam->button_cam_start),
 /* 		       "clicked", */
 /* 		       "released", */
 		       "pressed",
-		       G_CALLBACK (on_button_dac_recstart),
+		       G_CALLBACK (on_button_dac_camstart),
 		       NULL);
 
 
 /*
  * Record de-activating button
  */
-    dac->cam->button_rec_stop = gtk_button_new_with_label(_("stop record"));
-    gtk_widget_ref(dac->cam->button_rec_stop);
+    dac->cam->button_cam_stop = gtk_button_new_with_label(_("stop camera"));
+    gtk_widget_ref(dac->cam->button_cam_stop);
     gtk_object_set_data_full(GTK_OBJECT (main_window),
-			     "button_rec_stop",
-			     dac->cam->button_rec_stop,
+			     "button_cam_stop",
+			     dac->cam->button_cam_stop,
 			     (GtkDestroyNotify) gtk_widget_unref);
-    gtk_widget_show(dac->cam->button_rec_stop);
+    gtk_widget_show(dac->cam->button_cam_stop);
     gtk_table_attach(GTK_TABLE(dac->table),
-		     dac->cam->button_rec_stop, 
+		     dac->cam->button_cam_stop, 
 		     1, 
 		     2, 
 		     2, 
@@ -2158,32 +2207,33 @@ create_dac (GnomeApp *main_window,
 		     0,
 		     0);
     gtk_tooltips_set_tip(gpiv->tooltips,
-			 dac->cam->button_rec_stop,
-			 _("Stops the recording of PIV images "
-                           "and cancels sending of trigger pulses"),
+			 dac->cam->button_cam_stop,
+			 _("Stops camera to record of PIV images "
+                           "and, eventually, cancels sending of trigger pulses"),
 			 NULL);
 
-    gtk_object_set_data(GTK_OBJECT (dac->cam->button_rec_stop),
+    gtk_object_set_data(GTK_OBJECT (dac->cam->button_cam_stop),
 			"gpiv",
 			gpiv);
-    g_signal_connect(GTK_OBJECT (dac->cam->button_rec_stop),
+    g_signal_connect(GTK_OBJECT (dac->cam->button_cam_stop),
 		       "enter",
-		       G_CALLBACK (on_button_dac_recstop_enter),
+		       G_CALLBACK (on_button_dac_camstop_enter),
 		       NULL);
-    g_signal_connect(GTK_OBJECT (dac->cam->button_rec_stop),
+    g_signal_connect(GTK_OBJECT (dac->cam->button_cam_stop),
 		       "leave",
 		       G_CALLBACK (on_widget_leave),
 		       NULL);
-    g_signal_connect(GTK_OBJECT (dac->cam->button_rec_stop),
+    g_signal_connect(GTK_OBJECT (dac->cam->button_cam_stop),
 		       "clicked",
-		       G_CALLBACK (on_button_dac_recstop),
+		       G_CALLBACK (on_button_dac_camstop),
 		       NULL);
-
+#endif /* ENABLE_CAM */
 
 /*
  * Setting initial values
  */
-    if (dac_par.ttime.mode == GPIV_TIMER_MODE__PERIODIC) {
+#ifdef ENABLE_CAM
+    if (gl_cam_par.mode == GPIV_CAM_MODE__PERIODIC) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
 				    (dac->trig->radiobutton_mouse_1),
                                     TRUE);
@@ -2193,38 +2243,57 @@ create_dac (GnomeApp *main_window,
                                     FALSE);
     }
 
-    if (dac_par.ttime.mode == GPIV_TIMER_MODE__DURATION) {
+    if (gl_cam_par.mode == GPIV_CAM_MODE__DURATION) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
 				    (dac->trig->radiobutton_mouse_2),
                                     TRUE);
     }
 
-    if (dac_par.ttime.mode == GPIV_TIMER_MODE__ONE_SHOT_IRQ) {
+#else
+#ifdef ENABLE_TRIG
+    if (trig_par.ttime.mode == GPIV_TIMER_MODE__PERIODIC) {
+	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
+				    (dac->trig->radiobutton_mouse_1),
+                                    TRUE);
+    } else {
+	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
+				    (dac->trig->radiobutton_mouse_1),
+                                    FALSE);
+    }
+
+    if (trig_par.ttime.mode == GPIV_TIMER_MODE__DURATION) {
+	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
+				    (dac->trig->radiobutton_mouse_2),
+                                    TRUE);
+    }
+
+    if (trig_par.ttime.mode == GPIV_TIMER_MODE__ONE_SHOT_IRQ) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
 				    (dac->trig->radiobutton_mouse_3),
                                     TRUE);
     }
 
-    if (dac_par.ttime.mode == GPIV_TIMER_MODE__TRIGGER_IRQ) {
+    if (trig_par.ttime.mode == GPIV_TIMER_MODE__TRIGGER_IRQ) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
 				    (dac->trig->radiobutton_mouse_4),
                                     TRUE);
     }
 
-    if (dac_par.ttime.mode == GPIV_TIMER_MODE__INCREMENT) {
+    if (trig_par.ttime.mode == GPIV_TIMER_MODE__INCREMENT) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
 				    (dac->trig->radiobutton_mouse_5),
                                     TRUE);
     }
 
-    if (dac_par.ttime.mode == GPIV_TIMER_MODE__DOUBLE) {
+    if (trig_par.ttime.mode == GPIV_TIMER_MODE__DOUBLE) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
 				    (dac->trig->radiobutton_mouse_6),
                                     TRUE);
     }
-
+#endif /* ENABLE_TRIG */
+#endif /* ENABLE_CAM */
 
     return dac;
 }
 
-#endif /* DISABLE_DAC */
+#endif /* ENABLE_DAC */
