@@ -28,6 +28,21 @@
 /*
  * Image header interface
  * $Log: imgh_interface.c,v $
+ * Revision 1.13  2007-11-23 16:24:07  gerber
+ * release 0.5.0: Kafka
+ *
+ * Revision 1.12  2007-06-06 17:00:48  gerber
+ * Retreives images/data from URI using Gnome Virtual File System.
+ *
+ * Revision 1.11  2007-03-22 16:00:32  gerber
+ * Added image processing tabulator
+ *
+ * Revision 1.10  2007-01-29 11:27:43  gerber
+ * added image formats png, gif, tif png, bmp, improved buffer display
+ *
+ * Revision 1.9  2006-09-18 07:27:06  gerber
+ * *** empty log message ***
+ *
  * Revision 1.8  2006/01/31 14:28:12  gerber
  * version 0.3.0
  *
@@ -78,8 +93,8 @@ create_imgh (GnomeApp *main_window,
  * Image Info window with data from header
  */
 {
-    GpivConsole * gpiv = gtk_object_get_data (GTK_OBJECT (main_window), "gpiv");
-    Imgheader * imgh = g_new0 (Imgheader, 1);
+    GpivConsole *gpiv = gtk_object_get_data (GTK_OBJECT (main_window), "gpiv");
+    Imgheader *imgh = g_new0 (Imgheader, 1);
 
 
     imgh->vbox_label = gtk_vbox_new (FALSE,
@@ -150,7 +165,7 @@ create_imgh (GnomeApp *main_window,
 
 
     imgh->viewport = gtk_viewport_new (NULL,
-				      NULL);
+                                       NULL);
     gtk_widget_ref (imgh->viewport);
     gtk_object_set_data_full (GTK_OBJECT (main_window),
 			     "imgh_viewport",
@@ -243,7 +258,7 @@ create_imgh (GnomeApp *main_window,
 
 
 
-    imgh->label_label_name = gtk_label_new ( _("name: "));
+    imgh->label_label_name = gtk_label_new ( _("file: "));
     gtk_widget_ref (imgh->label_label_name);
     gtk_object_set_data_full (GTK_OBJECT (main_window),
 			     "imgh_label_label_name",
@@ -274,8 +289,8 @@ create_imgh (GnomeApp *main_window,
 
 
     imgh->table5 = gtk_table_new (9,
-				 2,
-				 FALSE);
+                                  2,
+                                  FALSE);
     gtk_widget_ref (imgh->table5);
     gtk_object_set_data_full (GTK_OBJECT (main_window),
 			     "imgh->table5", 
@@ -424,7 +439,7 @@ create_imgh (GnomeApp *main_window,
     gtk_widget_ref (imgh->label_label_depth);
     gtk_object_set_data_full (GTK_OBJECT (main_window),
 			     "imh_label_label_depth",
-			     imgh->label_label_nrows,
+			     imgh->label_label_depth,
 			     (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (imgh->label_label_depth);
     gtk_table_attach (GTK_TABLE (imgh->table5),
@@ -696,7 +711,7 @@ create_imgh (GnomeApp *main_window,
 
 
     imgh->spinbutton_adj_sscale_px =
-	gtk_adjustment_new (gpiv_var.img_span_px,
+	gtk_adjustment_new (gpiv_var->img_span_px,
 			   1, 
 			   IMAGE_WIDTH_MAX, 
 			   1,
@@ -756,7 +771,7 @@ create_imgh (GnomeApp *main_window,
 
 
     imgh->spinbutton_adj_sscale_mm =
-	gtk_adjustment_new (gpiv_var.img_length_mm,
+	gtk_adjustment_new (gpiv_var->img_length_mm,
 			   0.0001, 
 			   500.0, 
 			   ADJ_STEP,
@@ -819,7 +834,7 @@ create_imgh (GnomeApp *main_window,
 
 
     imgh->spinbutton_adj_sscale =
-	gtk_adjustment_new (image_par.s_scale,
+	gtk_adjustment_new (gl_image_par->s_scale,
 			   0, 
 			   ADJ_MAX, 
 			   ADJ_STEP,
@@ -881,7 +896,7 @@ create_imgh (GnomeApp *main_window,
 
 
     imgh->spinbutton_adj_tscale =
-	gtk_adjustment_new (image_par.t_scale,
+	gtk_adjustment_new (gl_image_par->t_scale,
 			   0,
 			   ADJ_MAX,
 			   ADJ_STEP,
@@ -921,7 +936,7 @@ create_imgh (GnomeApp *main_window,
 
 
 
-    imgh->table2 = gtk_table_new (4,
+    imgh->table2 = gtk_table_new (16,
 				 2,
 				 FALSE);
     gtk_widget_ref (imgh->table2);
@@ -961,7 +976,7 @@ create_imgh (GnomeApp *main_window,
 
 
     imgh->spinbutton_adj_colpos =
-	gtk_adjustment_new (image_par.z_off_x,
+	gtk_adjustment_new (gl_image_par->z_off_x,
 			   ADJ_MIN,
 			   ADJ_MAX,
 			   ADJ_STEP,
@@ -1025,7 +1040,7 @@ create_imgh (GnomeApp *main_window,
 
 
     imgh->spinbutton_adj_rowpos =
-	gtk_adjustment_new (image_par.z_off_y,
+	gtk_adjustment_new (gl_image_par->z_off_y,
 			   ADJ_MIN,
 			   ADJ_MAX,
 			   ADJ_STEP,
@@ -1116,9 +1131,9 @@ create_imgh (GnomeApp *main_window,
 		       "changed",
 		       G_CALLBACK (on_entry_imgh_title),
 		       imgh->entry_imgtitle);
-    if (image_par.title_logic) {
+    if (gl_image_par->title__set) {
         gtk_entry_set_text(GTK_ENTRY(imgh->entry_imgtitle), 
-                           image_par.title);
+                           gl_image_par->title);
     }
 
 /*
@@ -1175,9 +1190,9 @@ create_imgh (GnomeApp *main_window,
 		       "changed",
 		       G_CALLBACK (on_entry_imgh_crdate),
 		       imgh->entry_crdate);
-    if (image_par.creation_date_logic) {
+    if (gl_image_par->creation_date__set) {
         gtk_entry_set_text(GTK_ENTRY(imgh->entry_crdate), 
-                           image_par.creation_date);
+                           gl_image_par->creation_date);
     }
 
 /*
@@ -1228,9 +1243,9 @@ create_imgh (GnomeApp *main_window,
 		       "changed",
 		       G_CALLBACK (on_entry_imgh_location),
 		       imgh->entry_location);
-    if (image_par.location_logic) {
+    if (gl_image_par->location__set) {
         gtk_entry_set_text(GTK_ENTRY(imgh->entry_location), 
-                           image_par.location);
+                           gl_image_par->location);
     }
 
 /*
@@ -1281,9 +1296,9 @@ create_imgh (GnomeApp *main_window,
 		       "changed",
 		       G_CALLBACK (on_entry_imgh_author),
 		       imgh->entry_author);
-    if (image_par.author_logic) {
+    if (gl_image_par->author__set) {
         gtk_entry_set_text(GTK_ENTRY(imgh->entry_author), 
-                           image_par.author);
+                           gl_image_par->author);
     }
 
 /*
@@ -1334,9 +1349,9 @@ create_imgh (GnomeApp *main_window,
 		       "changed",
 		       G_CALLBACK (on_entry_imgh_software),
 		       imgh->entry_software);
-    if (image_par.software_logic) {
+    if (gl_image_par->software__set) {
         gtk_entry_set_text(GTK_ENTRY(imgh->entry_software), 
-                           image_par.software);
+                           gl_image_par->software);
     }
 
 /*
@@ -1387,9 +1402,9 @@ create_imgh (GnomeApp *main_window,
 		       "changed",
 		       G_CALLBACK (on_entry_imgh_source),
 		       imgh->entry_source);
-    if (image_par.source_logic) {
+    if (gl_image_par->source__set) {
         gtk_entry_set_text(GTK_ENTRY(imgh->entry_source), 
-                           image_par.source);
+                           gl_image_par->source);
     }
 
 /*
@@ -1440,9 +1455,9 @@ create_imgh (GnomeApp *main_window,
 		       "changed",
 		       G_CALLBACK (on_entry_imgh_usertext),
 		       imgh->entry_usertext);
-    if (image_par.usertext_logic) {
+    if (gl_image_par->usertext__set) {
         gtk_entry_set_text(GTK_ENTRY(imgh->entry_usertext), 
-                           image_par.usertext);
+                           gl_image_par->usertext);
     }
 
 /*
@@ -1493,9 +1508,9 @@ create_imgh (GnomeApp *main_window,
 		       "changed",
 		       G_CALLBACK (on_entry_imgh_warning),
 		       imgh->entry_warning);
-    if (image_par.warning_logic) {
+    if (gl_image_par->warning__set) {
         gtk_entry_set_text(GTK_ENTRY(imgh->entry_warning), 
-                           image_par.warning);
+                           gl_image_par->warning);
     }
 
 /*
@@ -1546,9 +1561,9 @@ create_imgh (GnomeApp *main_window,
 		       "changed",
 		       G_CALLBACK (on_entry_imgh_disclaimer),
 		       imgh->entry_disclaimer);
-    if (image_par.disclaimer_logic) {
+    if (gl_image_par->disclaimer__set) {
         gtk_entry_set_text(GTK_ENTRY(imgh->entry_disclaimer), 
-                           image_par.disclaimer);
+                           gl_image_par->disclaimer);
     }
 
 /*
@@ -1599,9 +1614,168 @@ create_imgh (GnomeApp *main_window,
 		       "changed",
 		       G_CALLBACK (on_entry_imgh_comment),
 		       imgh->entry_comment);
-    if (image_par.comment_logic) {
+    if (gl_image_par->comment__set) {
         gtk_entry_set_text(GTK_ENTRY(imgh->entry_comment), 
-                           image_par.comment);
+                           gl_image_par->comment);
+    }
+
+/*
+ * entry for copyright
+ */
+    imgh->label_copyright = gtk_label_new ( _("Copyright: "));
+    gtk_widget_ref (imgh->label_copyright);
+    gtk_object_set_data_full (GTK_OBJECT (main_window),
+			     "imgh_label_copyright",
+			     imgh->label_copyright,
+			     (GtkDestroyNotify) gtk_widget_unref);
+    gtk_widget_show (imgh->label_copyright);
+    gtk_table_attach (GTK_TABLE (imgh->table2),
+		     imgh->label_copyright, 
+		     0, 
+		     1, 
+		     11, 
+		     12,
+		     (GtkAttachOptions) (GTK_FILL),
+		     (GtkAttachOptions) (0),
+		     0,
+		     0);
+
+
+
+    imgh->entry_copyright = gtk_entry_new ();
+    gtk_widget_ref (imgh->entry_copyright);
+    gtk_object_set_data_full (GTK_OBJECT (main_window),
+			     "imgh_entry_copyright",
+			     imgh->entry_copyright,
+			     (GtkDestroyNotify) gtk_widget_unref);
+    gtk_widget_show (imgh->entry_copyright);
+    gtk_table_attach (GTK_TABLE (imgh->table2),
+		     imgh->entry_copyright, 
+		     1, 
+		     2, 
+		     11, 
+		     12,
+		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		     (GtkAttachOptions) (0),
+		     0,
+		     0);
+
+    gtk_object_set_data (GTK_OBJECT (imgh->entry_copyright),
+			"imgh",
+			imgh);
+    g_signal_connect (GTK_OBJECT (imgh->entry_copyright),
+		       "changed",
+		       G_CALLBACK (on_entry_imgh_copyright),
+		       imgh->entry_copyright);
+    if (gl_image_par->copyright__set) {
+        gtk_entry_set_text(GTK_ENTRY(imgh->entry_copyright), 
+                           gl_image_par->copyright);
+    }
+
+/*
+ * entry for email
+ */
+    imgh->label_email = gtk_label_new ( _("Email: "));
+    gtk_widget_ref (imgh->label_email);
+    gtk_object_set_data_full (GTK_OBJECT (main_window),
+			     "imgh_label_email",
+			     imgh->label_email,
+			     (GtkDestroyNotify) gtk_widget_unref);
+    gtk_widget_show (imgh->label_email);
+    gtk_table_attach (GTK_TABLE (imgh->table2),
+		     imgh->label_email, 
+		     0, 
+		     1, 
+		     13, 
+		     14,
+		     (GtkAttachOptions) (GTK_FILL),
+		     (GtkAttachOptions) (0),
+		     0,
+		     0);
+
+
+
+    imgh->entry_email = gtk_entry_new ();
+    gtk_widget_ref (imgh->entry_email);
+    gtk_object_set_data_full (GTK_OBJECT (main_window),
+			     "imgh_entry_email",
+			     imgh->entry_email,
+			     (GtkDestroyNotify) gtk_widget_unref);
+    gtk_widget_show (imgh->entry_email);
+    gtk_table_attach (GTK_TABLE (imgh->table2),
+		     imgh->entry_email, 
+		     1, 
+		     2, 
+		     13, 
+		     14,
+		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		     (GtkAttachOptions) (0),
+		     0,
+		     0);
+
+    gtk_object_set_data (GTK_OBJECT (imgh->entry_email),
+			"imgh",
+			imgh);
+    g_signal_connect (GTK_OBJECT (imgh->entry_email),
+		       "changed",
+		       G_CALLBACK (on_entry_imgh_email),
+		       imgh->entry_email);
+    if (gl_image_par->email__set) {
+        gtk_entry_set_text(GTK_ENTRY(imgh->entry_email), 
+                           gl_image_par->email);
+    }
+
+/*
+ * entry for url
+ */
+    imgh->label_url = gtk_label_new ( _("Url: "));
+    gtk_widget_ref (imgh->label_url);
+    gtk_object_set_data_full (GTK_OBJECT (main_window),
+			     "imgh_label_url",
+			     imgh->label_url,
+			     (GtkDestroyNotify) gtk_widget_unref);
+    gtk_widget_show (imgh->label_url);
+    gtk_table_attach (GTK_TABLE (imgh->table2),
+		     imgh->label_url, 
+		     0, 
+		     1, 
+		     15, 
+		     16,
+		     (GtkAttachOptions) (GTK_FILL),
+		     (GtkAttachOptions) (0),
+		     0,
+		     0);
+
+
+
+    imgh->entry_url = gtk_entry_new ();
+    gtk_widget_ref (imgh->entry_url);
+    gtk_object_set_data_full (GTK_OBJECT (main_window),
+			     "imgh_entry_url",
+			     imgh->entry_url,
+			     (GtkDestroyNotify) gtk_widget_unref);
+    gtk_widget_show (imgh->entry_url);
+    gtk_table_attach (GTK_TABLE (imgh->table2),
+		     imgh->entry_url, 
+		     1, 
+		     2, 
+		     15, 
+		     16,
+		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+		     (GtkAttachOptions) (0),
+		     0,
+		     0);
+
+    gtk_object_set_data (GTK_OBJECT (imgh->entry_url),
+			"imgh",
+			imgh);
+    g_signal_connect (GTK_OBJECT (imgh->entry_url),
+		       "changed",
+		       G_CALLBACK (on_entry_imgh_url),
+		       imgh->entry_url);
+    if (gl_image_par->url__set) {
+        gtk_entry_set_text(GTK_ENTRY(imgh->entry_url), 
+                           gl_image_par->url);
     }
 
     return imgh;
