@@ -26,6 +26,15 @@
 /*
  * PIV Post-processing interface
  * $Log: pivpost_interface.c,v $
+ * Revision 1.10  2007-11-23 16:24:08  gerber
+ * release 0.5.0: Kafka
+ *
+ * Revision 1.9  2007-01-29 11:27:44  gerber
+ * added image formats png, gif, tif png, bmp, improved buffer display
+ *
+ * Revision 1.8  2006-09-18 07:27:06  gerber
+ * *** empty log message ***
+ *
  * Revision 1.7  2006/01/31 14:28:12  gerber
  * version 0.3.0
  *
@@ -154,7 +163,7 @@ create_pivpost (GnomeApp *main_window,
  * main table for PIVPOST
  */
     post->table = gtk_table_new (2,
-				2,
+				 2,
 				FALSE);
     gtk_widget_ref (post->table);
     gtk_object_set_data_full (GTK_OBJECT (main_window),
@@ -233,7 +242,7 @@ create_pivpost (GnomeApp *main_window,
  * KEEP DISABLED
  */
 /*      spinbutton_adj_post_sscale = */
-/* 	gtk_adjustment_new (piv_post_par.s_scale, 0, 1279, 1, 100, 100); */
+/* 	gtk_adjustment_new (gl_post_par.s_scale, 0, 1279, 1, 100, 100); */
 /*
  * end of KEEP DISABLED
  */
@@ -297,7 +306,7 @@ create_pivpost (GnomeApp *main_window,
  * KEEP DISABLED
  */
 /*     spinbutton_adj_post_tscale = */
-/* 	gtk_adjustment_new (piv_post_par.t_scale, 0, 1279, 1, 100, 100); */
+/* 	gtk_adjustment_new (gl_post_par.t_scale, 0, 1279, 1, 100, 100); */
 /*
  * end of KEEP DISABLED
  */
@@ -362,7 +371,7 @@ create_pivpost (GnomeApp *main_window,
  * KEEP DISABLED
  */
 /*     spinbutton_adj_post_colpos = */
-/* 	gtk_adjustment_new (piv_post_par.z_off_x, 0, Z_OFF_MAX, 1, 100, */
+/* 	gtk_adjustment_new (gl_post_par.z_off_x, 0, Z_OFF_MAX, 1, 100, */
 /* 			   100); */
 /*
  * end of KEEP DISABLED
@@ -428,7 +437,7 @@ create_pivpost (GnomeApp *main_window,
  * KEEP DISABLED
  */
 /*     spinbutton_adj_post_rowpos = */
-/* 	gtk_adjustment_new (piv_post_par.z_off_y, 0, Z_OFF_MAX, 1, 100, */
+/* 	gtk_adjustment_new (gl_post_par.z_off_y, 0, Z_OFF_MAX, 1, 100, */
 /* 			   100); */
 /*
  * end of KEEP DISABLED
@@ -570,7 +579,7 @@ create_pivpost (GnomeApp *main_window,
  
 
      post->spinbutton_adj_suavg =
-/* ARG1: piv_post_par.s_savg */
+/* ARG1: gl_post_par.s_savg */
 /* 	gtk_adjustment_new (0. , */
 /* 			   0, */
 /* 			   1, */
@@ -642,7 +651,7 @@ create_pivpost (GnomeApp *main_window,
  
 
      post->spinbutton_adj_svavg =
-/* ARG1: piv_post_par.s_savg */
+/* ARG1: gl_post_par.s_savg */
 	gtk_adjustment_new (0.0 ,
 			   -100,
 			   100,
@@ -696,7 +705,7 @@ create_pivpost (GnomeApp *main_window,
     gtk_table_attach (GTK_TABLE (post->table_savg),
 		     post->button_savg, 
 		     0,
-		     2,
+		     1,
 		     2,
 		     3,
 		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
@@ -725,49 +734,6 @@ create_pivpost (GnomeApp *main_window,
 		       NULL);
 
 
-/*
- * button to add averages or zero offset displacements / velocities
- */
-    post->button_addavg = gtk_button_new_with_label ( _("add"));
-    gtk_widget_ref (post->button_addavg);
-    gtk_object_set_data_full (GTK_OBJECT (main_window),
-			     "post_button_addavg",
-			     post->button_addavg,
-			     (GtkDestroyNotify) gtk_widget_unref);
-    gtk_widget_show (post->button_addavg);
-    gtk_table_attach (GTK_TABLE (post->table_savg),
-		     post->button_addavg, 
-		     0,
-		     1,
-		     3,
-		     4,
-		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		     (GtkAttachOptions) (0),
-		     0,
-		     0);
-    gtk_tooltips_set_tip(gpiv->tooltips,
-			 post->button_addavg,
-			  _("Adds the spatial averages or offset "
-"displacements / velocities, from each estimator"),
-			 NULL);
-
-    gtk_object_set_data (GTK_OBJECT (post->button_addavg), 
-			"post",
-			post);
-    g_signal_connect (GTK_OBJECT (post->button_addavg),
-		       "enter",
-		       G_CALLBACK (on_button_post_addavg_enter),
-		       NULL);
-    g_signal_connect (GTK_OBJECT (post->button_addavg),
-		       "leave",
-		       G_CALLBACK (on_widget_leave),
-		       NULL);
-    g_signal_connect (GTK_OBJECT (post->button_addavg),
-		       "clicked",
-		       G_CALLBACK (on_button_post_addavg),
-		       NULL);
-
-
 /*
  * button to subtract averages or zero offset displacements / velocities
  */
@@ -782,8 +748,8 @@ create_pivpost (GnomeApp *main_window,
 		     post->button_subavg, 
 		     1,
 		     2,
+		     2,
 		     3,
-		     4,
 		     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		     (GtkAttachOptions) (0),
 		     0,
@@ -1128,7 +1094,7 @@ create_pivpost (GnomeApp *main_window,
 /*
  *Define which button is switched on at start up time
  */
-    if (piv_post_par.diff_type == 2) {
+    if (gl_post_par->diff_type == 2) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (post->radiobutton_vorstra_diffscheme_3),
 				    TRUE);
@@ -1178,7 +1144,7 @@ create_pivpost (GnomeApp *main_window,
 /*
  *Define which button is switched on at start up time
  */
-    if (piv_post_par.diff_type == 3) {
+    if (gl_post_par->diff_type == 3) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (post->radiobutton_vorstra_diffscheme_4),
 				    TRUE);
@@ -1217,31 +1183,31 @@ create_pivpost (GnomeApp *main_window,
  * end of the tabulator as diff_scheme button Circulation might be
  * enabled or disabled
  */
-    if (piv_post_par.operator_vorstra == 0) {
+    if (gl_post_par->operator_vorstra == 0) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (post->radiobutton_vorstra_output_1),
 				    TRUE);
-    } else if (piv_post_par.operator_vorstra == 1) {
+    } else if (gl_post_par->operator_vorstra == 1) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (post->radiobutton_vorstra_output_2),
 				    TRUE);
-    } else if (piv_post_par.operator_vorstra == 2) {
+    } else if (gl_post_par->operator_vorstra == 2) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (post->radiobutton_vorstra_output_3),
 				    TRUE);
     }
 
 
-    if (piv_post_par.diff_type == 0) {
+    if (gl_post_par->diff_type == 0) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (post->radiobutton_vorstra_diffscheme_1),
 				    TRUE);
     }
-    if (piv_post_par.diff_type == 1) {
+    if (gl_post_par->diff_type == 1) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (post->radiobutton_vorstra_diffscheme_2),
 				    TRUE);
-    } else if (piv_post_par.diff_type == 2) {
+    } else if (gl_post_par->diff_type == 2) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (post->radiobutton_vorstra_diffscheme_3),
 				    TRUE);
