@@ -27,6 +27,15 @@
 /*
  * PIV Validation interface
  * $Log: pivvalid_interface.c,v $
+ * Revision 1.11  2007-12-19 08:42:35  gerber
+ * debugged
+ *
+ * Revision 1.10  2007-11-23 16:24:08  gerber
+ * release 0.5.0: Kafka
+ *
+ * Revision 1.9  2007-01-29 11:27:44  gerber
+ * added image formats png, gif, tif png, bmp, improved buffer display
+ *
  * Revision 1.8  2006/01/31 14:28:13  gerber
  * version 0.3.0
  *
@@ -657,7 +666,7 @@ create_pivvalid (GnomeApp *main_window,
     gtk_tooltips_set_tip(gpiv->tooltips,
 			 valid->button_peaklck,
 			  _("shows histogram of sub-pixel displacements "
-"in order to check on peak-locking effects"),
+"to check on peak-locking effects"),
 			 NULL);
 
     gtk_object_set_data (GTK_OBJECT (valid->button_peaklck), 
@@ -824,7 +833,7 @@ Only this histogram will be saved"),
 
 
     valid->spinbutton_adj_errvec_neighbors = 
-        gtk_adjustment_new (piv_valid_par.neighbors,
+        gtk_adjustment_new (gl_valid_par->neighbors,
 			    3,
 			    GPIV_VALIDPAR_MAX__NEIGHBORS,
 			    2,
@@ -892,7 +901,7 @@ Only this histogram will be saved"),
 
 
     valid->spinbutton_adj_errvec_yield = 
-        gtk_adjustment_new (piv_valid_par.data_yield,
+        gtk_adjustment_new (gl_valid_par->data_yield,
 			   0.0,
 			   1.0,
 			   0.01,
@@ -959,7 +968,7 @@ Only this histogram will be saved"),
 
 
     valid->spinbutton_adj_errvec_res = 
-        gtk_adjustment_new (piv_valid_par.residu_max,
+        gtk_adjustment_new (gl_valid_par->residu_max,
 			   0., 
 			   THRESHOLD_MAX,
 			   0.1, 
@@ -1096,7 +1105,7 @@ Only this histogram will be saved"),
 		       "clicked",
 		       G_CALLBACK (on_radiobutton_valid_errvec_residu),
 		       NULL);
-    if (piv_valid_par.residu_type == 2) {
+    if (gl_valid_par->residu_type == 2) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (valid->radiobutton_errvec_residu_normmedian),
 				    TRUE);
@@ -1140,7 +1149,7 @@ Only this histogram will be saved"),
 		       "clicked",
 		       G_CALLBACK (on_radiobutton_valid_errvec_residu),
 		       NULL);
-    if (piv_valid_par.residu_type == 1) {
+    if (gl_valid_par->residu_type == 1) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (valid->radiobutton_errvec_residu_median),
 				    TRUE);
@@ -1185,7 +1194,7 @@ Only this histogram will be saved"),
 		       "toggled",
 		       G_CALLBACK (on_radiobutton_valid_errvec_residu),
 		       NULL);
-    if (piv_valid_par.residu_type == 0) {
+    if (gl_valid_par->residu_type == 0) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (valid->radiobutton_errvec_residu_snr),
 				    TRUE);
@@ -1272,7 +1281,7 @@ Only this histogram will be saved"),
 		       "toggled",
 		       G_CALLBACK (on_radiobutton_valid_errvec_subst),
 		       NULL);
-    if (piv_valid_par.subst_type == GPIV_VALID_SUBSTYPE__NONE) {
+    if (gl_valid_par->subst_type == GPIV_VALID_SUBSTYPE__NONE) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (valid->radiobutton_errvec_subst_0),
 				    TRUE);
@@ -1362,7 +1371,7 @@ Only this histogram will be saved"),
 		       "toggled", 
 		       G_CALLBACK (on_radiobutton_valid_errvec_subst),
 		       NULL);
-   if (piv_valid_par.subst_type == GPIV_VALID_SUBSTYPE__MEDIAN ) {  
+   if (gl_valid_par->subst_type == GPIV_VALID_SUBSTYPE__MEDIAN ) {  
      gtk_toggle_button_set_state  (GTK_TOGGLE_BUTTON 
 				  (valid->radiobutton_errvec_subst_2),
 				  TRUE);
@@ -1407,7 +1416,7 @@ Only this histogram will be saved"),
 		       "toggled",
 		       G_CALLBACK (on_radiobutton_valid_errvec_subst),
 		       NULL);
-    if (piv_valid_par.subst_type == GPIV_VALID_SUBSTYPE__COR_PEAK) {
+    if (gl_valid_par->subst_type == GPIV_VALID_SUBSTYPE__COR_PEAK) {
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON
 				    (valid->radiobutton_errvec_subst_3),
 				    TRUE);
