@@ -27,6 +27,15 @@
 
 /*
  * $Log: print.c,v $
+ * Revision 1.8  2007-11-23 16:24:08  gerber
+ * release 0.5.0: Kafka
+ *
+ * Revision 1.7  2007-06-06 17:00:48  gerber
+ * Retreives images/data from URI using Gnome Virtual File System.
+ *
+ * Revision 1.6  2007-01-29 11:27:44  gerber
+ * added image formats png, gif, tif png, bmp, improved buffer display
+ *
  * Revision 1.5  2006/01/31 14:28:13  gerber
  * version 0.3.0
  *
@@ -81,7 +90,7 @@ ttp://developer.gnome.org/doc/API/2.0/gtk/GtkDialog.html#GtkDialogFlags
 /* 
  * Main window of print dialog
  */
-	g_warning("create_print_dialog:: 1");
+	if (gpiv_par->verbose) g_warning("create_print_dialog:: 1");
 
 
 /*
@@ -118,12 +127,12 @@ ttp://developer.gnome.org/doc/API/2.0/gtk/GtkDialog.html#GtkDialogFlags
 			       FALSE,
 			       FALSE,
 			       FALSE);
-	g_warning("create_print_dialog:: 1.3");
+	if (gpiv_par->verbose) g_warning("create_print_dialog:: 1.3");
 	gtk_window_set_wmclass (GTK_WINDOW (pri->dialog),
 				"gpiv print", 
 				"");
 
-	g_warning("create_print_dialog:: 1.4");
+	if (gpiv_par->verbose) g_warning("create_print_dialog:: 1.4");
 
 
 /*
@@ -793,17 +802,18 @@ print_on_context(/* gpaint_image * image, */
  */
 {
     double matrix[6] = { 1, 0, 0, 1, 0, 0 };
-    gnome_print_beginpage(pc, display_act->fname_base);
+    gnome_print_beginpage(pc, display_act->file_uri_name);
 
     gnome_print_concat(pc, matrix);
     gnome_print_translate(pc, 0, 0);
-    gnome_print_scale(pc, gpiv_par.img_width, gpiv_par.img_height);
+    gnome_print_scale(pc, display_act->img->image->header->ncolumns,
+		      display_act->img->image->header->nrows);
 
     gnome_print_rgbaimage(pc,
-                          gdk_pixbuf_get_pixels(display_act->img.pixbuf1),
-                          gpiv_par.img_width,
-                          gpiv_par.img_height, 
-			  display_act->img.rgb_img_width);
+                          gdk_pixbuf_get_pixels(display_act->img->pixbuf1),
+                          display_act->img->image->header->ncolumns,
+                          display_act->img->image->header->nrows, 
+			  display_act->img->rgb_img_width);
 
     gnome_print_showpage(pc);
     return 1;
@@ -1028,7 +1038,7 @@ on_button_browse(GtkWidget *widget,
 				  G_CALLBACK( gtk_widget_destroy),
 				  GTK_OBJECT(filew));
 	gtk_file_selection_set_filename(GTK_FILE_SELECTION(filew),
-					gpiv_var.fname_last_print);
+					gpiv_var->fname_last_print);
 	gtk_widget_show(filew);
 	gtk_object_set_data(GTK_OBJECT(GTK_FILE_SELECTION(filew)), 
 			    "pri",
